.. -*- mode: rst -*-

|AppVeyor|_ |Codecov|_ |ReadTheDocs|_

.. |AppVeyor| image:: https://ci.appveyor.com/api/projects/status/github/big-o/skdag?branch=main&svg=true
.. _AppVeyor: https://ci.appveyor.com/project/big-o/skdag

.. |Codecov| image:: https://codecov.io/gh/big-o/skdag/branch/main/graph/badge.svg
.. _Codecov: https://codecov.io/gh/big-o/skdag

.. |ReadTheDocs| image:: https://readthedocs.org/projects/skdag/badge/?version=latest
.. _ReadTheDocs: https://skdag.readthedocs.io/en/latest/?badge=latest

skdag - A more flexible alternative to scikit-learn Pipelines
=============================================================

.. _scikit-learn: https://scikit-learn.org

**skdag** brings the flexibility of Directed Acyclic Graphs (DAGs) to scikit-learn_.

It enables the construction of complex workflows, including model stacking, to allow
data to flow through multiple estimators, with one or more start/endpoints.

.. _documentation: https://skdag.readthedocs.io/

Refer to the documentation_ for usage details.
